@@ -30,8 +30,8 @@ int32_t SPVM__Sys__IO__INIT_STDIN(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
-
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
@@ -48,7 +48,7 @@ int32_t SPVM__Sys__IO__INIT_STDOUT(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
@@ -66,7 +66,71 @@ int32_t SPVM__Sys__IO__INIT_STDERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (error_id) { return error_id; }
   
   
-  env->set_field_byte_by_name(env, stack, obj_stream, "no_need_free", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_stream;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__IO__INIT_SPVM_STDIN(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* runtime = env->runtime;
+  
+  FILE* spvm_stdin = env->api->runtime->get_spvm_stdin(runtime);
+  
+  FILE* stream = spvm_stdin;
+  
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_stream;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__IO__INIT_SPVM_STDOUT(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* runtime = env->runtime;
+  
+  FILE* spvm_stdout = env->api->runtime->get_spvm_stdout(runtime);
+  
+  FILE* stream = spvm_stdout;
+  
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_stream;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__IO__INIT_SPVM_STDERR(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* runtime = env->runtime;
+  
+  FILE* spvm_stderr = env->api->runtime->get_spvm_stderr(runtime);
+  
+  FILE* stream = spvm_stderr;
+  
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_stream;
@@ -256,6 +320,10 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = stack[0].ival;
   
+  if (!(fd >= 0)) {
+    return env->die(env, stack, "$fd must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
+  }
+  
   void* obj_mode = stack[1].oval;
   
   if (!obj_mode) {
