@@ -18,7 +18,7 @@ C<Sys::IO> is the class for the file IO.
 
 =head2 open
 
-  static method open : int ($path : string, $flags : int, $mode : int = 0);
+C<static method open : int ($path : string, $flags : int, $mode : int = 0);>
 
 Given a pathname for a file, open() returns a file descriptor, a small, nonnegative integer for use in subsequent system calls (read(2), write(2), lseek(2), fcntl(2), etc.). The file descriptor returned by a successful call will be the lowest-numbered file descriptor not currently open for the process.
 
@@ -28,7 +28,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 read
 
-  static method read : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);
+C<static method read : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);>
 
 read() attempts to read up to count bytes from file descriptor fd into the buf starting at buf + buf_offset.
 
@@ -36,7 +36,7 @@ See the L<read|https://linux.die.net/man/2/read> function in Linux.
 
 =head2 write
 
-  static method write : int ($fd : int, $buf : string, $count : int, $buf_offset : int = 0);
+C<static method write : int ($fd : int, $buf : string, $count : int, $buf_offset : int = 0);>
 
 write() writes up to count bytes from the buf pointed buf + buf_offset to the file referred to by the file descriptor fd.
 
@@ -44,7 +44,7 @@ See the L<write|https://linux.die.net/man/2/write> function in Linux.
 
 =head2 lseek
 
-  static method lseek : long ($fd : int, $offset : long, $whence : int);
+C<static method lseek : long ($fd : int, $offset : long, $whence : int);>
 
 The lseek() function repositions the offset of the open file associated with the file descriptor fd to the argument offset according to the directive whence as follows:
 
@@ -54,7 +54,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 close
 
-  static method close : int ($fd : int);
+C<static method close : int ($fd : int);>
 
 close() closes a file descriptor, so that it no longer refers to any file and may be reused. Any record locks (see fcntl(2)) held on the file it was associated with, and owned by the process, are removed (regardless of the file descriptor that was used to obtain the lock).
 
@@ -62,7 +62,7 @@ See the L<close|https://linux.die.net/man/2/close> function in Linux.
 
 =head2 fopen
 
-  static method fopen : Sys::IO::FileStream ($path : string, $mode : string);
+C<static method fopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($path : string, $mode : string);>
 
 The fopen() function opens the file whose name is the string pointed to by path and associates a stream with it.
 
@@ -72,7 +72,7 @@ The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 fdopen
 
-  static method fdopen : Sys::IO::FileStream ($fd : int, $mode : string);
+C<static method fdopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($fd : int, $mode : string);>
 
 The fdopen() function associates a stream with the existing file descriptor, fd. The mode of the stream (one of the values "r", "r+", "w", "w+", "a", "a+") must be compatible with the mode of the file descriptor. The file position indicator of the new stream is set to that belonging to fd, and the error and end-of-file indicators are cleared. Modes "w" or "w+" do not cause truncation of the file. The file descriptor is not dup'ed, and will be closed when the stream created by fdopen() is closed. The result of applying fdopen() to a shared memory object is undefined.
 
@@ -80,9 +80,13 @@ See the L<fdopen|https://linux.die.net/man/3/fdopen> function in Linux.
 
 The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
+Exceptions:
+
+$fd must be greater than or equal to 0. Otherwise an exception is thrown.
+
 =head2 fileno
 
-  static method fileno : int ($stream : Sys::IO::FileStream);
+C<static method fileno : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The function fileno() examines the argument stream and returns its integer descriptor.
 
@@ -92,7 +96,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 fread
 
-  static method fread : int ($ptr : mutable string, $size : int, $nmemb : int, $stream : Sys::IO::FileStream, $ptr_offset : int = 0);
+C<static method fread : int ($ptr : mutable string, $size : int, $nmemb : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $ptr_offset : int = 0);>
 
 The function fread() reads nmemb elements of data, each size bytes long, from the stream pointed to by stream, storing them at the location given by ptr + ptr_offset.
 
@@ -100,7 +104,7 @@ See the L<fread|https://linux.die.net/man/3/fread> function in Linux.
 
 =head2 feof
 
-  static method feof : int ($stream : Sys::IO::FileStream);
+C<static method feof : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The function feof() tests the end-of-file indicator for the stream pointed to by stream, returning nonzero if it is set. The end-of-file indicator can only be cleared by the function clearerr().
 
@@ -110,7 +114,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 ferror
 
-  static method ferror : int ($stream : Sys::IO::FileStream);
+C<static method ferror : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The function ferror() tests the error indicator for the stream pointed to by stream, returning nonzero if it is set. The error indicator can only be reset by the clearerr() function.
 
@@ -120,7 +124,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 clearerr
 
-  static method clearerr : void ($stream : Sys::IO::FileStream);
+C<static method clearerr : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The function clearerr() clears the end-of-file and error indicators for the stream pointed to by stream.
 
@@ -130,7 +134,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 getc
 
-  static method getc : int ($stream : Sys::IO::FileStream);
+C<static method getc : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 getc() is equivalent to fgetc() except that it may be implemented as a macro which evaluates stream more than once.
 
@@ -140,7 +144,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 fgets
 
-  static method fgets : mutable string ($s : mutable string, $size : int, $stream : Sys::IO::FileStream, $s_offset : int = 0);
+C<static method fgets : mutable string ($s : mutable string, $size : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $s_offset : int = 0);>
 
 fgets() reads in at most one less than size characters from stream and stores them into the buf pointed to by s + s_offset. Reading stops after an EOF or a newline. If a newline is read, it is stored into the buf. A terminating null byte (aq\0aq) is stored after the last character in the buf.
 
@@ -148,7 +152,7 @@ See the L<fgets|https://linux.die.net/man/3/fgets> function in Linux.
 
 =head2 fwrite
 
-  static method fwrite : int ($ptr : string, $size : int, $nmemb : int, $stream : Sys::IO::FileStream, $ptr_offset : int = 0);
+C<static method fwrite : int ($ptr : string, $size : int, $nmemb : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $ptr_offset : int = 0);>
 
 The function fwrite() writes nmemb elements of data, each size bytes long, to the stream pointed to by stream, obtaining them from the location given by ptr + ptr_offset.
 
@@ -158,7 +162,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 fseek
 
-  static method fseek : int ($stream : Sys::IO::FileStream, $offset : long, $whence : int);
+C<static method fseek : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $offset : long, $whence : int);>
 
 The fseek() function sets the file position indicator for the stream pointed to by stream. The new position, measured in bytes, is obtained by adding offset bytes to the position specified by whence. If whence is set to SEEK_SET, SEEK_CUR, or SEEK_END, the offset is relative to the start of the file, the current position indicator, or end-of-file, respectively. A successful call to the fseek() function clears the end-of-file indicator for the stream and undoes any effects of the ungetc(3) function on the same stream.
 
@@ -170,7 +174,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 ftell
 
-  static method ftell : long ($stream : Sys::IO::FileStream);
+C<static method ftell : long ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The ftell() function obtains the current value of the file position indicator for the stream pointed to by stream.
 
@@ -180,7 +184,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 fclose
 
-  static method fclose : int ($stream : Sys::IO::FileStream);
+C<static method fclose : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The fclose() function flushes the stream pointed to by fp (writing any bufed output data using fflush(3)) and closes the underlying file descriptor.
 
@@ -190,7 +194,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 =head2 fflush
 
-  static method fflush : int ($stream : Sys::IO::FileStream);
+C<static method fflush : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 For output streams, fflush() forces a write of all user-space bufed data for the given output or update stream via the stream's underlying write function. For input streams, fflush() discards any bufed data that has been fetched from the underlying file, but has not been consumed by the application. The open status of the stream is unaffected.
 
@@ -198,7 +202,7 @@ See the L<fflush|https://linux.die.net/man/3/fflush> function in Linux.
 
 =head2 flock
 
-  static method flock : int ($fd : int, $operation : int);
+C<static method flock : int ($fd : int, $operation : int);>
 
 Apply or remove an advisory lock on the open file specified by fd. The argument operation is one of the following:
 
@@ -208,7 +212,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 mkdir
 
-  static method mkdir : int ($path : string, $mode : int);
+C<static method mkdir : int ($path : string, $mode : int);>
 
 mkdir() attempts to create a directory named pathname.
 
@@ -218,7 +222,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 umask
 
-  static method umask : int ($mode : int);
+C<static method umask : int ($mode : int);>
 
 umask() sets the calling process's file mode creation mask (umask) to mask & 0777 (i.e., only the file permission bits of mask are used), and returns the previous value of the mask.
 
@@ -226,7 +230,7 @@ See the L<umask|https://linux.die.net/man/2/umask> function in Linux.
 
 =head2 rmdir
 
-  static method rmdir : int ($path : string);
+C<static method rmdir : int ($path : string);>
 
 rmdir() deletes a directory, which must be empty.
 
@@ -234,7 +238,7 @@ See the L<rmdir|https://linux.die.net/man/2/rmdir> function in Linux.
 
 =head2 unlink
 
-  static method unlink : int ($pathname : string);
+C<static method unlink : int ($pathname : string);>
 
 unlink() deletes a name from the file system. If that name was the last link to a file and no processes have the file open the file is deleted and the space it was using is made available for reuse.
 
@@ -242,7 +246,7 @@ See the L<unlink|https://linux.die.net/man/2/unlink> function in Linux.
 
 =head2 rename
 
-  static method rename : int ($oldpath : string, $newpath : string);
+C<static method rename : int ($oldpath : string, $newpath : string);>
 
 rename() renames a file, moving it between directories if required. Any other hard links to the file (as created using link(2)) are unaffected. Open file descriptors for oldpath are also unaffected.
 
@@ -250,7 +254,7 @@ See the L<rename|https://linux.die.net/man/2/rename> function in Linux.
 
 =head2 getcwd
 
-  static method getcwd : mutable string ($buf : mutable string, $size : int);
+C<static method getcwd : mutable string ($buf : mutable string, $size : int);>
 
 The getcwd() function copies an absolute pathname of the current working directory to the array pointed to by buf, which is of length size.
 
@@ -258,7 +262,7 @@ See the L<getcwd|https://linux.die.net/man/2/getcwd> function in Linux.
 
 =head2 _getdcwd
 
-  static method _getdcwd : mutable string ($drive : int, $buffer : mutable string, $maxlen : int);
+C<static method _getdcwd : mutable string ($drive : int, $buffer : mutable string, $maxlen : int);>
 
 Gets the full path of the current working directory on the specified drive.
 
@@ -266,7 +270,7 @@ See the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-library/refere
 
 =head2 realpath
 
-  static method realpath : mutable string ($path : string, $resolved_path : mutable string);
+C<static method realpath : mutable string ($path : string, $resolved_path : mutable string);>
 
 realpath() expands all symbolic links and resolves references to /./, /../ and extra '/' characters in the null-terminated string named by path to produce a canonicalized absolute pathname. The resulting pathname is stored as a null-terminated string, up to a maximum of PATH_MAX bytes, in the buf pointed to by resolved_path. The resulting path will have no symbolic link, /./ or /../ components.
 
@@ -274,7 +278,7 @@ See the L<realpath|https://linux.die.net/man/3/realpath> function in Linux.
 
 =head2 _fullpath
 
-  native static method _fullpath : mutable string ($absPath : mutable string, $relPath : string, $maxLength : int);
+C<native static method _fullpath : mutable string ($absPath : mutable string, $relPath : string, $maxLength : int);>
 
 Creates an absolute or full path name for the specified relative path name.
 
@@ -282,7 +286,7 @@ See the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime-library/refer
 
 =head2 chdir
 
-  static method chdir : int ($path : string);
+C<static method chdir : int ($path : string);>
 
 chdir() changes the current working directory of the calling process to the directory specified in path.
 
@@ -290,7 +294,7 @@ See the L<chdir|https://linux.die.net/man/2/chdir> function in Linux.
 
 =head2 chmod
 
-  static method chmod : int ($path : string, $mode :int);
+C<static method chmod : int ($path : string, $mode :int);>
 
 chmod() changes the permissions of the file specified whose pathname is given in path, which is dereferenced if it is a symbolic link.
 
@@ -300,7 +304,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 chown
 
-  static method chown : int ($path : string, $owner : int, $group : int);
+C<static method chown : int ($path : string, $owner : int, $group : int);>
 
 chown() changes the ownership of the file specified by path, which is dereferenced if it is a symbolic link.
 
@@ -308,7 +312,7 @@ See the L<chown|https://linux.die.net/man/2/chown> function in Linux.
 
 =head2 truncate
 
-  static method truncate : int ($path : string, $length : long);
+C<static method truncate : int ($path : string, $length : long);>
 
 The truncate() and ftruncate() functions cause the regular file named by path or referenced by fd to be truncated to a size of precisely length bytes.
 
@@ -316,7 +320,7 @@ See the L<truncate|https://linux.die.net/man/2/truncate> function in Linux.
 
 =head2 symlink
 
-  static method symlink : int ($oldpath : string, $newpath : string);
+C<static method symlink : int ($oldpath : string, $newpath : string);>
 
 symlink() creates a symbolic link named newpath which contains the string oldpath.
 
@@ -324,7 +328,7 @@ See the L<symlink|https://linux.die.net/man/2/symlink> function in Linux.
 
 =head2 readlink
 
-  static method readlink : int ($path : string, $buf : mutable string, $bufsiz : int);
+C<static method readlink : int ($path : string, $buf : mutable string, $bufsiz : int);>
 
 readlink() places the contents of the symbolic link path in the buf buf, which has size bufsiz. readlink() does not append a null byte to buf. It will truncate the contents (to a length of bufsiz characters), in case the buf is too small to hold all of the contents.
 
@@ -332,13 +336,13 @@ See the L<readlink|https://linux.die.net/man/2/readlink> function in Linux.
 
 =head2 get_readlink_buffer_size
 
-  native static method get_readlink_buffer_size : int ($path : string);
+C<native static method get_readlink_buffer_size : int ($path : string);>
 
 Gets the L</"readlink"> needed buffer size.
 
 =head2 opendir
 
-  static method opendir : Sys::IO::DirStream ($dir : string);
+C<static method opendir : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> ($dir : string);>
 
 The opendir() function opens a directory stream corresponding to the directory name, and returns a pointer to the directory stream. The stream is positioned at the first entry in the directory.
 
@@ -348,7 +352,7 @@ The return value is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 =head2 closedir
 
-  static method closedir : int ($dirp : Sys::IO::DirStream);
+C<static method closedir : int ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
 
 The closedir() function closes the directory stream associated with dirp. A successful call to closedir() also closes the underlying file descriptor associated with dirp. The directory stream descriptor dirp is not available after this call.
 
@@ -358,7 +362,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 =head2 readdir
 
-  static method readdir : Sys::IO::Dirent ($dirp : Sys::IO::DirStream); # Non-thead safe
+C<static method readdir : L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>); # Non-thead safe>
 
 The readdir() function returns a pointer to a dirent structure representing the next directory entry in the directory stream pointed to by dirp. It returns NULL on reaching the end of the directory stream or if an error occurred.
 
@@ -370,7 +374,7 @@ The return value is a L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> object.
 
 =head2 rewinddir
 
-  static method rewinddir : void ($dirp : Sys::IO::DirStream);
+C<static method rewinddir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
 
 The rewinddir() function resets the position of the directory stream dirp to the beginning of the directory.
 
@@ -380,7 +384,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 =head2 telldir
 
-  static method telldir : long ($dirp : Sys::IO::DirStream);
+C<static method telldir : long ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
 
 The telldir() function returns the current location associated with the directory stream dirp.
 
@@ -390,7 +394,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 =head2 seekdir
 
-  static method seekdir : void ($dirp : Sys::IO::DirStream, $offset : long);
+C<static method seekdir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>, $offset : long);>
 
 The seekdir() function sets the location in the directory stream from which the next readdir(2) call will start. seekdir() should be used with an offset returned by telldir(3).
 See the L<seekdir|https://linux.die.net/man/3/seekdir> function in Linux.
@@ -399,7 +403,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 =head2 utime
 
-  static method utime : int ($filename : string, $times : Sys::IO::Utimbuf);
+C<static method utime : int ($filename : string, $times : L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf>);>
 
 The utime() system call changes the access and modification times of the inode specified by filename to the actime and modtime fields of times respectively.
 
@@ -409,13 +413,13 @@ The buf is a L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf> object.
 
 =head2 access_raw
 
-  static method access_raw : int ($pathname : string, $mode : int);
+C<static method access_raw : int ($pathname : string, $mode : int);>
 
 The same as L</"access">, but even if the return value is C<-1>, an exception will not be thrown.
 
 =head2 access
 
-  static method access : int ($pathname : string, $mode : int);
+C<static method access : int ($pathname : string, $mode : int);>
 
 access() checks whether the calling process can access the file pathname. If pathname is a symbolic link, it is dereferenced.
 
@@ -425,13 +429,13 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 eaccess_raw
 
-  static method eaccess_raw : int ($pathname : string, $mode : int);
+C<static method eaccess_raw : int ($pathname : string, $mode : int);>
 
 The same as L</"eaccess">, but even if the return value is C<-1>, an exception will not be thrown.
 
 =head2 eaccess
 
-  static method eaccess : int ($pathname : string, $mode : int);
+C<static method eaccess : int ($pathname : string, $mode : int);>
 
 eaccess() checks whether the calling process can eaccess the file pathname. If pathname is a symbolic link, it is dereferenced.
 
@@ -441,25 +445,25 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 eaccess_raw
 
-  static method eaccess : int ($pathname : string, $mode : int)
+C<static method eaccess : int ($pathname : string, $mode : int)>
 
 The same as L</"eaccess">, but even if the return value is C<-1>, an exception will not be thrown.
 
 =head2 eaccess
 
-  static method eaccess : int ($pathname : string, $mode : int)
+C<static method eaccess : int ($pathname : string, $mode : int)>
 
 Emulates C<eaccess> using L</"faccessat">.
 
 =head2 stat_raw
 
-  static method stat_raw : int ($path : string, $stat : Sys::IO::Stat);
+C<static method stat_raw : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
 
 The same as L</"stat">, but even if the return value is C<-1>, an exception will not be thrown.
 
 =head2 stat
 
-  static method stat : int ($path : string, $stat : Sys::IO::Stat);
+C<static method stat : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
 
 These functions return information about a file. No permissions are required on the file itself, but-in the case of stat() and lstat() - execute (search) permission is required on all of the directories in path that lead to the file.
 
@@ -471,13 +475,13 @@ The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 =head2 lstat_raw
 
-  static method lstat_raw : int ($path : string, $stat : Sys::IO::Stat);
+C<static method lstat_raw : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
 
 The same as L</"lstat">, but even if the return value is C<-1>, an exception will not be thrown.
 
 =head2 lstat
 
-  static method lstat : int ($path : string, $stat : Sys::IO::Stat);
+C<static method lstat : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
 
 These functions return information about a file. No permissions are required on the file itself, but-in the case of stat() and lstat() - execute (search) permission is required on all of the directories in path that lead to the file.
 
@@ -489,7 +493,7 @@ The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 =head2 fcntl
 
-  static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|Sys::IO::Flock|object = undef);
+C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|Sys::IO::Flock|object = undef);>
 
 fcntl() performs one of the operations described below on the open file descriptor fd. The operation is determined by cmd.
 
@@ -499,7 +503,7 @@ The command argument can receive a L<Sys::IO::Flock|SPVM::Sys::IO::Flock> object
 
 =head2 ftruncate
 
-  static method ftruncate : int ($fd : int, $length : long);
+C<static method ftruncate : int ($fd : int, $length : long);>
 
 The ftruncate() functions cause the regular file named by referenced by fd to be truncated to a size of precisely length bytes.
 
@@ -507,7 +511,7 @@ See L<ftruncate(2) - Linux man page|https://linux.die.net/man/2/ftruncate> in Li
 
 =head2 ungetc
 
-  static method ungetc : int ($c : int, $stream : Sys::IO::FileStream);
+C<static method ungetc : int ($c : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 ungetc() pushes c back to stream, cast to unsigned char, where it is available for subsequent read operations. Pushed-back characters will be returned in reverse order; only one pushback is guaranteed.
 
@@ -515,7 +519,7 @@ See L<ungetc(3) - Linux man page|https://linux.die.net/man/3/ungetc> in Linux.
 
 =head2 fsync
 
-  static method fsync : int ($fd : int);
+C<static method fsync : int ($fd : int);>
 
 fsync() transfers ("flushes") all modified in-core data of (i.e., modified buffer cache pages for) the file referred to by the file descriptor fd to the disk device (or other permanent storage device) so that all changed information can be retrieved even after the system crashed or was rebooted.
 
@@ -523,13 +527,13 @@ See L<fsync(2) - Linux man page|https://linux.die.net/man/2/fsync> in Linux.
 
 =head2 fstat_raw
 
-  static method fstat_raw : int ($fd : int, $stat : Sys::IO::Stat);
+C<static method fstat_raw : int ($fd : int, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
 
 The same as L</"fstat">, but even if the return value is C<-1>, an exception will not be thrown.
 
 =head2 fstat
 
-  static method fstat : int ($fd : int, $stat : Sys::IO::Stat);
+C<static method fstat : int ($fd : int, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
 
 fstat() is identical to stat(), except that the file to be stat-ed is specified by the file descriptor fd.
 
@@ -539,7 +543,7 @@ The C<$stat> is a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 =head2 freopen
 
-  static method freopen : Sys::IO::FileStream ($path : string, $mode : string, $stream : Sys::IO::FileStream);
+C<static method freopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($path : string, $mode : string, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The freopen() function opens the file whose name is the string pointed to by path and associates the stream pointed to by stream with it.
 
@@ -547,7 +551,7 @@ See L<freopen(3) - Linux man page|https://linux.die.net/man/3/freopen> in Linux.
 
 =head2 setvbuf
 
-  static method setvbuf : int ($stream : Sys::IO::FileStream, $buf : mutable string, $mode : int, $size : int);
+C<static method setvbuf : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $mode : int, $size : int);>
 
 The setvbuf() function may be used on any open stream to change its buffer.
 
@@ -557,7 +561,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 =head2 setbuf
 
-  static method setbuf : void ($stream : Sys::IO::FileStream, $buf : mutable string);
+C<static method setbuf : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string);>
 
 The same as the following code using L</"setvbuf">.
 
@@ -573,7 +577,7 @@ The same as the following code using L</"setvbuf">.
 
 =head2 setbuffer
 
-  static method setbuffer : void ($stream : Sys::IO::FileStream, $buf : mutable string, $size : int);
+C<static method setbuffer : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $size : int);>
 
 The same as the following code using L</"setvbuf">.
 
@@ -589,7 +593,7 @@ The same as the following code using L</"setvbuf">.
 
 =head2 setlinebuf
 
-  static method setlinebuf : void ($stream : Sys::IO::FileStream);
+C<static method setlinebuf : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
 The same as the following code using L</"setvbuf">.
 
@@ -598,7 +602,7 @@ The same as the following code using L</"setvbuf">.
 
 =head2 stdin
 
-  static method stdin : Sys::IO::FileStream ();
+C<static method stdin : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
 Returns a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object that has the pointer to the stream that C<stdin> in C<C language> returns.
 
@@ -606,7 +610,7 @@ See L<stdin(3) - Linux man page|https://linux.die.net/man/3/stdin> in Linux.
 
 =head2 stdout
 
-  static method stdout : Sys::IO::FileStream ();
+C<static method stdout : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
 Returns a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object that has the pointer to the stream that C<stdout> in C<C language> returns.
 
@@ -614,12 +618,30 @@ See L<stdout(3) - Linux man page|https://linux.die.net/man/3/stdout> in Linux.
 
 =head2 stderr
 
-  static method stderr : Sys::IO::FileStream ();
+C<static method stderr : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
 Returns a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object that has the pointer to the stream that C<stderr> in C<C language> returns.
 
 See L<stderr(3) - Linux man page|https://linux.die.net/man/3/stderr> in Linux.
 
+=head2 spvm_stdin
+
+C<static method spvm_stdin : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the stdin opened by the SPVM language.
+
+=head2 spvm_stdout
+
+C<static method spvm_stdout : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the stdin opened by the SPVM language.
+
+=head2 spvm_stderr
+
+C<static method spvm_stderr : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the stdin opened by the SPVM language.
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
