@@ -26,13 +26,13 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
 =head2 closed
 
-  has closed : ro byte;
+C<has closed : ro byte;>
 
 The directory stream is closed.
 
 =head1 Instance Methods
 
-  method DESTROY : void ();
+C<method DESTROY : void ();>
 
 The destructor.
 
