@@ -26,7 +26,7 @@ int32_t SPVM__Sys__Poll__PollfdArray__new(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The length must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  struct pollfd* fds = env->new_memory_stack(env, stack, sizeof(struct pollfd) * length);
+  struct pollfd* fds = env->new_memory_block(env, stack, sizeof(struct pollfd) * length);
   
   int32_t fields_length = 1;
   void* obj_self = env->new_pointer_object_by_name(env, stack, "Sys::Poll::PollfdArray", fds, &error_id, __func__, FILE_NAME, __LINE__);
@@ -48,7 +48,7 @@ int32_t SPVM__Sys__Poll__PollfdArray__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack)
   
   assert(fds);
   
-  env->free_memory_stack(env, stack, fds);
+  env->free_memory_block(env, stack, fds);
   env->set_pointer(env, stack, obj_self, NULL);
   
   return 0;
@@ -66,11 +66,11 @@ int32_t SPVM__Sys__Poll__PollfdArray__fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (error_id) { return error_id; }
   
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be less than the value of the length field.", __func__, FILE_NAME, __LINE__);
   }
 
   struct pollfd* fds = env->get_pointer(env, stack, obj_self);
@@ -94,11 +94,11 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (error_id) { return error_id; }
   
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be less than the value of the length field.", __func__, FILE_NAME, __LINE__);
   }
 
   int32_t fd = stack[2].ival;
@@ -118,14 +118,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__events(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be less than the value of the length field.", __func__, FILE_NAME, __LINE__);
   }
 
   struct pollfd* fds = env->get_pointer(env, stack, obj_self);
@@ -145,14 +145,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_events(SPVM_ENV* env, SPVM_VALUE* stac
 
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be less than the value of the length field.", __func__, FILE_NAME, __LINE__);
   }
 
   int16_t events = stack[2].ival;
@@ -172,13 +172,13 @@ int32_t SPVM__Sys__Poll__PollfdArray__revents(SPVM_ENV* env, SPVM_VALUE* stack)
   
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be less than the value of the length field.", __func__, FILE_NAME, __LINE__);
   }
 
   struct pollfd* fds = env->get_pointer(env, stack, obj_self);
@@ -198,14 +198,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_revents(SPVM_ENV* env, SPVM_VALUE* sta
 
   int32_t index = stack[1].ival;
   if (!(index >= 0)) {
-    return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   if (!(index < length)) {
-    return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$index must be less than the value of the length field.", __func__, FILE_NAME, __LINE__);
   }
 
   int16_t revents = stack[2].ival;
