@@ -26,7 +26,7 @@ int32_t SPVM__Sys__Select__Fd_set__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t error_id = 0;
 
-  fd_set* type_fd_set = env->new_memory_stack(env, stack, sizeof(fd_set));
+  fd_set* type_fd_set = env->new_memory_block(env, stack, sizeof(fd_set));
   
   void* obj_fd_set = env->new_pointer_object_by_name(env, stack, "Sys::Select::Fd_set", type_fd_set, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
@@ -47,7 +47,7 @@ int32_t SPVM__Sys__Select__Fd_set__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(type_fd_set);
   
-  env->free_memory_stack(env, stack, type_fd_set);
+  env->free_memory_block(env, stack, type_fd_set);
   env->set_pointer(env, stack, obj_fd_set, NULL);
   
   return 0;
