@@ -2481,7 +2481,7 @@ int32_t SPVM__Sys__Socket__Constant__IN6ADDR_ANY(SPVM_ENV* env, SPVM_VALUE* stac
 #ifdef IN6ADDR_ANY_INIT
   struct in6_addr address_init = IN6ADDR_ANY_INIT;
   
-  struct in6_addr* address = env->new_memory_stack(env, stack, sizeof(struct in6_addr));
+  struct in6_addr* address = env->new_memory_block(env, stack, sizeof(struct in6_addr));
   
   int32_t error_id = 0;
   void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address, &error_id, __func__, FILE_NAME, __LINE__);
@@ -2501,7 +2501,7 @@ int32_t SPVM__Sys__Socket__Constant__IN6ADDR_LOOPBACK(SPVM_ENV* env, SPVM_VALUE*
 #ifdef IN6ADDR_LOOPBACK_INIT
   struct in6_addr address_init = IN6ADDR_LOOPBACK_INIT;
   
-  struct in6_addr* address = env->new_memory_stack(env, stack, sizeof(struct in6_addr));
+  struct in6_addr* address = env->new_memory_block(env, stack, sizeof(struct in6_addr));
   
   int32_t error_id = 0;
   void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address, &error_id, __func__, FILE_NAME, __LINE__);
