@@ -12,7 +12,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__In__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t error_id = 0;
   
-  struct sockaddr_in* socket_address = env->new_memory_stack(env, stack, sizeof(struct sockaddr_in));
+  struct sockaddr_in* socket_address = env->new_memory_block(env, stack, sizeof(struct sockaddr_in));
 
   void* obj_socket_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In", socket_address, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
@@ -30,7 +30,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__In__DESTROY(SPVM_ENV* env, SPVM_VALUE* stac
   
   assert(socket_address);
   
-  env->free_memory_stack(env, stack, socket_address);
+  env->free_memory_block(env, stack, socket_address);
   env->set_pointer(env, stack, obj_socket_address, NULL);
   
   return 0;
@@ -68,7 +68,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__In__sin_addr(SPVM_ENV* env, SPVM_VALUE* sta
   
   struct in_addr address = socket_address->sin_addr;
 
-  struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+  struct in_addr* address_ret = env->new_memory_block(env, stack, sizeof(struct in_addr));
   *address_ret = address;
 
   void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
