@@ -29,7 +29,7 @@ int32_t SPVM__Sys__Time__localtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error_id = 0;
   
   time_t time = (time_t)stack[0].lval;
-  struct tm* st_tm = env->new_memory_stack(env, stack, sizeof(struct tm));
+  struct tm* st_tm = env->new_memory_block(env, stack, sizeof(struct tm));
   
 #ifdef _WIN32
   localtime_s(st_tm, &time);
@@ -50,7 +50,7 @@ int32_t SPVM__Sys__Time__gmtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error_id = 0;
   
   time_t time = (time_t)stack[0].lval;
-  struct tm* st_tm = env->new_memory_stack(env, stack, sizeof(struct tm));
+  struct tm* st_tm = env->new_memory_block(env, stack, sizeof(struct tm));
   
 #ifdef _WIN32
   gmtime_s(st_tm, &time);
